@@ -1,6 +1,5 @@
-"""from . import StripeAdapter
+from . import StripeAdapter
 from . import Schemas
 from . import BigQuery
-"""
 
 __version__ = '0.2.0'
